# coding: utf-8

# Copyright 2018, 2021 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_insight_model as ti

class TestConceptAnnotation(object):

    @staticmethod
    def test_concept_annotation(annotation_list=None):
        if annotation_list is not None:
            for annotation in annotation_list:
                if annotation.id is not None:
                    assert len(annotation.id) > 0
                if annotation.type is not None:
                    assert len(annotation.type) > 0
                assert annotation.begin >= 0
                assert annotation.end > annotation.begin
                assert annotation.covered_text is not None
                if annotation.semantic_type is not None:
                    assert len(annotation.semantic_type) > 0
                if annotation.uid is not None:
                    assert annotation.uid > 0
                if annotation.cui is not None:
                    assert len(annotation.cui) > 0
                if annotation.preferred_name is not None:
                    assert len(annotation.preferred_name) > 0
                if annotation.source is not None:
                    assert len(annotation.source) > 0
                if annotation.source_version is not None:
                    assert len(annotation.source_version) > 0
                if annotation.icd9_code is not None:
                    assert len(annotation.icd9_code) > 0
                if annotation.icd10_code is not None:
                    assert len(annotation.icd10_code) > 0
                if annotation.nci_code is not None:
                    assert len(annotation.nci_code) > 0
                if annotation.snomed_concept_id is not None:
                    assert len(annotation.snomed_concept_id) > 0
                if annotation.mesh_id is not None:
                    assert len(annotation.mesh_id) > 0
                if annotation.rx_norm_id is not None:
                    assert len(annotation.rx_norm_id) > 0
                if annotation.loinc_id is not None:
                    assert len(annotation.loinc_id) > 0
                if annotation.vocabs is not None:
                    assert len(annotation.vocabs) > 0
                if annotation.section_normalized_name is not None:
                    assert len(annotation.section_normalized_name) > 0
                if annotation.section_surface_form is not None:
                    assert len(annotation.section_surface_form) > 0
                if annotation.cpt_code is not None:
                    assert len(annotation.cpt_code) > 0
                if annotation.disambiguation_data is not None:
                    assert annotation.disambiguation_data.validity is not None
                if annotation.insight_model_data is not None:
                    ti.TestInsightModel.test_insight_model_data(annotation.insight_model_data)
                if annotation.rule_id is not None:
                    assert len(annotation.rule_id) > 0
                if annotation.derived_from is not None:
                    for entry in annotation.derived_from:
                        assert entry is not None
                        if entry.uid is not None:
                            assert entry.uid >= 0
                        if entry.selection_label is not None:
                            assert len(entry.selection_label) > 0
                if annotation.temporal is not None:
                    for entry in annotation.temporal:
                        assert entry is not None



# coding: utf-8

# Copyright 2018, 2021 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

class TestInsightModel(object):

    @staticmethod
    def test_insight_model_data(data=None):
        if data is not None:
            assert data is not None
            if data.diagnosis is not None:
                assert len(data.diagnosis._to_dict()) > 0
                if data.diagnosis.usage is not None:
                    assert len(data.diagnosis.usage._to_dict()) > 0
                if data.diagnosis.modifiers is not None:
                    assert len(data.diagnosis.modifiers._to_dict()) > 0
            if data.procedure is not None:
                assert len(data.procedure._to_dict()) > 0
                if data.procedure.usage is not None:
                    assert len(data.procedure.usage._to_dict()) > 0
                if data.procedure.task is not None:
                    assert len(data.procedure.task._to_dict()) > 0
                if data.procedure.type is not None:
                    assert len(data.procedure.type._to_dict()) > 0
                if data.procedure.modifiers is not None:
                    assert len(data.procedure.modifiers._to_dict()) > 0
            if data.medication is not None:
                assert len(data.medication._to_dict()) > 0
                if data.medication.usage is not None:
                    assert len(data.medication.usage._to_dict()) > 0
                if data.medication.started is not None:
                    assert len(data.medication.started._to_dict()) > 0
                if data.medication.stopped is not None:
                    assert len(data.medication.stopped._to_dict()) > 0
                if data.medication.dose_changed is not None:
                    assert len(data.medication.dose_changed._to_dict()) > 0
                if data.medication.adverse is not None:
                    assert len(data.medication.adverse._to_dict()) > 0
            if data.normality is not None:
                assert len(data.normality._to_dict()) > 0
                if data.normality.usage is not None:
                    assert len(data.normality.usage._to_dict()) > 0
                if data.normality.evidence is not None:
                    for entry in data.normality.evidence:
                        assert entry is not None
            if data.tobacco is not None:
                assert len(data.tobacco._to_dict()) > 0
                if data.tobacco.usage is not None:
                    assert len(data.tobacco.usage._to_dict()) > 0
                if data.tobacco.use_status is not None:
                    assert len(data.tobacco.use_status._to_dict()) > 0
            if data.alcohol is not None:
                assert len(data.alcohol._to_dict()) > 0
                if data.alcohol.usage is not None:
                    assert len(data.alcohol.usage._to_dict()) > 0
                if data.alcohol.use_status is not None:
                    assert len(data.alcohol.use_status._to_dict()) > 0
                if data.alcohol.use_qualifier is not None:
                    assert len(data.alcohol.use_qualifier._to_dict()) > 0
            if data.illicit_drug is not None:
                assert len(data.illicit_drug._to_dict()) > 0
                if data.illicit_drug.usage is not None:
                    assert len(data.illicit_drug.usage._to_dict()) > 0
                if data.illicit_drug.use_status is not None:
                    assert len(data.illicit_drug.use_status._to_dict()) > 0
                if data.illicit_drug.use_dimension is not None:
                    assert len(data.illicit_drug.use_dimension._to_dict()) > 0
            if data.substance is not None:
                assert len(data.substance._to_dict()) > 0
                if data.substance.treatment is not None:
                    assert len(data.substance.treatment._to_dict()) > 0



# coding: utf-8

# Copyright 2018 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_disambiguation as td

class TestCancerDiagnosisAnnotation(object):

    @staticmethod
    def test_cancer_diagnosis(annotation_list=None):
        if annotation_list is not None:
            for annotation in annotation_list:
                if annotation.id is not None:
                    assert len(annotation.id) > 0
                if annotation.type is not None:
                    assert len(annotation.type) > 0
                assert annotation.begin is not None
                assert annotation.end is not None
                assert annotation.covered_text is not None
                if annotation.uid is not None:
                    assert annotation.uid > 0
                if annotation.cui is not None:
                    assert len(annotation.cui) > 0
                if annotation.modality is not None:
                    assert len(annotation.modality) > 0
                if annotation.section_normalized_name is not None:
                    assert len(annotation.section_normalized_name) > 0
                if annotation.section_surface_form is not None:
                    assert len(annotation.section_surface_form) > 0
                if annotation.disambiguation_data is not None:
                    td.TestDisambiguation.test_disambiguation_data(annotation.disambiguation_data)



# coding: utf-8

# Copyright 2021 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.\

from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_annotation as ta
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_attribute_values as tav
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_assistance_annotation as taa
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_cancer_diagnosis as tcd
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_concept_annotation as tca
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_concept_value_annotation as tcva
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_ejection_fraction as tef
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_lab_value as tlv
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_medication as tm
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_negated_span as tns
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_procedure as tp
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_smoking as ts
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_symptom_disease as tsd
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_section as tsec
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_nlu_entities as tne
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_relation as tr
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_spelling_correction as tsc
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_spell_corrected_text as tsct
from ibm_whcs_sdk.annotator_for_clinical_data.tests.common import test_temporal_span as tts

class TestUnstructuredContainer(object):

    @staticmethod
    def test_unstructured_container(data=None):
        if data is not None:
            if data.allergy_ind is not None:
                ta.TestAnnotation.test_annotation(data.allergy_ind)
            if data.allergy_medication_ind is not None:
                ta.TestAnnotation.test_annotation(data.allergy_medication_ind)
            if data.attribute_values is not None:
                tav.TestAttributeValueAnnotation.test_attribute_values(data.attribute_values)
            if data.bathing_assistance_ind is not None:
                taa.TestAssistanceAnnotation.test_assistance_annotation(data.bathing_assistance_ind)
            if data.ica_cancer_diagnosis_ind is not None:
                tcd.TestCancerDiagnosisAnnotation.test_cancer_diagnosis(data.ica_cancer_diagnosis_ind)
            if data.concepts is not None:
                tca.TestConceptAnnotation.test_concept_annotation(data.concepts)
            if data.concept_values is not None:
                tcva.TestConceptValueAnnotation.test_concept_value(data.concept_values)
            if data.dressing_assistance_ind is not None:
                taa.TestAssistanceAnnotation.test_assistance_annotation(data.dressing_assistance_ind)
            if data.eating_assistance_ind is not None:
                taa.TestAssistanceAnnotation.test_assistance_annotation(data.eating_assistance_ind)
            if data.ejection_fraction_ind is not None:
                tef.TestEjectionFractionAnnotation.test_ejection_fraction(data.ejection_fraction_ind)
            if data.hypothetical_spans is not None:
                ta.TestAnnotation.test_annotation(data.hypothetical_spans)
            if data.email_address_ind is not None:
                ta.TestAnnotation.test_annotation(data.email_address_ind)
            if data.lab_value_ind is not None:
                tlv.TestLabValueAnnotation.test_lab_value_annotation(data.lab_value_ind)
            if data.medication_ind is not None:
                tm.TestMedicationAnnotation.test_medication_annotation(data.medication_ind)
            if data.location_ind is not None:
                ta.TestAnnotation.test_annotation(data.location_ind)
            if data.person_ind is not None:
                ta.TestAnnotation.test_annotation(data.person_ind)
            if data.u_s_phone_number_ind is not None:
                ta.TestAnnotation.test_annotation(data.u_s_phone_number_ind)
            if data.medical_institution_ind is not None:
                ta.TestAnnotation.test_annotation(data.medical_institution_ind)
            if data.organization_ind is not None:
                ta.TestAnnotation.test_annotation(data.organization_ind)
            if data.negated_spans is not None:
                tns.TestNegatedSpanAnnotation.test_negated_span(data.negated_spans)
            if data.procedure_ind is not None:
                tp.TestProcedureAnnotation.test_procedure_annotation(data.procedure_ind)
            if data.seeing_assistance_ind is not None:
                taa.TestAssistanceAnnotation.test_assistance_annotation(data.seeing_assistance_ind)
            if data.smoking_ind is not None:
                ts.TestSmokingAnnotation.test_smoking_annotation(data.smoking_ind)
            if data.symptom_disease_ind is not None:
                tsd.TestSymptomDiseaseAnnotation.test_symptom_disease(data.symptom_disease_ind)
            if data.toileting_assistance_ind is not None:
                taa.TestAssistanceAnnotation.test_assistance_annotation(data.toileting_assistance_ind)
            if data.walking_assistance_ind is not None:
                taa.TestAssistanceAnnotation.test_assistance_annotation(data.walking_assistance_ind)
            if data.sections is not None:
                tsec.TestSectionAnnotation.test_section_annotation(data.sections)
            if data.nlu_entities is not None:
                tne.TestNluEntitiesAnnotation.test_nlu_entities(data.nlu_entities)
            if data.relations is not None:
                tr.TestRelationAnnotation.test_relation_annotation(data.relations)
            if data.spelling_corrections is not None:
                tsc.TestSpellingCorrection.test_spelling_correction(data.spelling_corrections)
            if data.spell_corrected_text is not None:
                tsct.TestSpellCorrectedText.test_spell_corrected_text(data.spell_corrected_text)
            if data.temporal_spans is not None:
                tts.TestTemporalSpanAnnotation.test_temporal_span(data.temporal_spans)
            if data.lines is not None:
                ta.TestAnnotation.test_annotation(data.lines)
            if data.sentences is not None:
                ta.TestAnnotation.test_annotation(data.sentences)
            if data.paragraphs is not None:
                ta.TestAnnotation.test_annotation(data.paragraphs)



# coding: utf-8

# Copyright 2018 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class TestAnnotatorOutput(object):

    @staticmethod
    def test_annotator_output(annotation_list=None):
        if annotation_list is not None:
            for annotation in annotation_list:
                if annotation.id is not None:
                    assert len(annotation.id) > 0
                if annotation.type is not None:
                    assert len(annotation.type) > 0
                assert annotation.begin > 0
                assert annotation.end > annotation.begin
                assert annotation.covered_text is not None
                if annotation.uid is not None:
                    assert annotation.uid > 0
                if annotation.cui is not None:
                    assert annotation.cui > 0
                if annotation.preferred_name is not None:
                    assert len(annotation.preferred_name) > 0
                if annotation.source is not None:
                    assert len(annotation.source) > 0
                if annotation.source_version is not None:
                    assert len(annotation.source_version) > 0
                if annotation.name is not None:
                    assert len(annotation.name) > 0
                if annotation.icd9_code is not None:
                    assert len(annotation.icd9_code) > 0
                if annotation.icd10_code is not None:
                    assert len(annotation.icd10_code) > 0
                if annotation.nci_code is not None:
                    assert len(annotation.nci_code) > 0
                if annotation.snomed_concept_id is not None:
                    assert len(annotation.snomed_concept_id) > 0
                if annotation.mesh_id is not None:
                    assert len(annotation.mesh_id) > 0
                if annotation.rx_norm_id is not None:
                    assert len(annotation.rx_norm_id) > 0
                if annotation.loinc_id is not None:
                    assert len(annotation.loinc_id) > 0
                if annotation.vocabs is not None:
                    assert len(annotation.vocabs) > 0
                if annotation.section_normalized_name is not None:
                    assert len(annotation.section_normalized_name) > 0
                if annotation.section_surface_form is not None:
                    assert len(annotation.section_surface_form) > 0
                if annotation.cpt_code is not None:
                    assert len(annotation.cpt_code) > 0
                if annotation.hcc_code is not None:
                    assert len(annotation.hcc_code) > 0
                if annotation.trigegr is not None:
                    assert len(annotation.trigger) > 0
                if annotation.dimension is not None:
                    assert len(annotation.dimension) > 0
                if annotation.first_value is not None:
                    assert len(annotation.first_value) > 0
                if annotation.second_value is not None:
                    assert len(annotation.second_value) > 0
                if annotation.ef_alphabetic_value_normalized_name is not None:
                    assert len(annotation.ef_alphabetic_value_normalized_name) > 0
                if annotation.ef_alphabetic_value_surface_form is not None:
                    assert len(annotation.ef_alphabetic_value_surface_form) > 0
                if annotation.ef_term_normalized_name is not None:
                    assert len(annotation.ef_term_normalized_name) > 0
                if annotation.ef_term_surface_form is not None:
                    assert len(annotation.ef_term_surface_form) > 0
                if annotation.ef_suffix_normalized_name is not None:
                    assert len(annotation.ef_suffix_normalized_name) > 0
                if annotation.ef_suffix_surface_form is not None:
                    assert len(annotation.ef_suffix_surface_form) > 0
                if annotation.lab_type_normalized_name is not None:
                    assert len(annotation.lab_type_normalized_name) > 0
                if annotation.lab_type_surface_form is not None:
                    assert len(annotation.lab_type_surface_form) > 0
                if annotation.procedure_normalized_name is not None:
                    assert len(annotation.procedure_normalized_name) > 0
                if annotation.procedure_surface_form is not None:
                    assert len(annotation.procedure_surface_form) > 0
                if annotation.smoke_term_normalized_name is not None:
                    assert len(annotation.smoke_term_normalized_name) > 0
                if annotation.smoke_term_surface_form is not None:
                    assert len(annotation.smoke_term_surface_form) > 0
                if annotation.symptom_disease_normalized_name is not None:
                    assert len(annotation.symptom_disease_normalized_name) > 0
                if annotation.symptom_disease_surface_form is not None:
                    assert len(annotation.symptom_disease_surface_form) > 0
                if annotation.low_value is not None:
                    assert len(annotation.low_value) > 0
                if annotation.participation is not None:
                    assert len(annotation.participation) > 0
                if annotation.current is not None:
                    assert len(annotation.current) > 0
                if annotation.lab_value is not None:
                    assert len(annotation.lab_value) > 0
                if annotation.date_in_milliseconds is not None:
                    assert len(annotation.date_in_milliseconds) > 0
                if annotation.is_range is not None:
                    assert len(annotation.is_range) > 0
#            if annotation.negated is not None:
#                assert annotation.negated isinstance(bool)
#            if annotation.hypothetical is not None:
#                assert annotation.hypothetical isinstance(bool)
                if annotation.drug is not None:
                    for drug_obj in annotation.drug:
                        assert drug_obj is not None
                if annotation.values is not None:
                    for value in annotation.values:
                        assert value is not None
                if annotation.concept is not None:
                    TestAnnotatorOutput.test_annotator_output(annotation.concept)
                if annotation.disambiguation_data is not None:
                    assert annotation.disambiguation_data.validity is not None
                if annotation.cancer is not None:
                    for cancer_obj in annotation.cancer:
                        assert cancer_obj is not None



# Copyright 2018 IBM All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .annotator_for_clinical_data_v1 import AnnotatorForClinicalDataV1
from .annotator_for_clinical_data_v1 import AcdCartridges
from .annotator_for_clinical_data_v1 import AcdFlow
from .annotator_for_clinical_data_v1 import AcdProfile
from .annotator_for_clinical_data_v1 import AllergyMedication
from .annotator_for_clinical_data_v1 import AnalyticFlowBeanInput
from .annotator_for_clinical_data_v1 import Annotation
from .annotator_for_clinical_data_v1 import Annotator
from .annotator_for_clinical_data_v1 import AnnotatorFlow
from .annotator_for_clinical_data_v1 import AssistanceAnnotation
from .annotator_for_clinical_data_v1 import AttributeValueAnnotation
from .annotator_for_clinical_data_v1 import AttributeValueEntry
from .annotator_for_clinical_data_v1 import CancerDiagnosis
from .annotator_for_clinical_data_v1 import Concept
from .annotator_for_clinical_data_v1 import ConceptValue
from .annotator_for_clinical_data_v1 import ConfigurationEntity
from .annotator_for_clinical_data_v1 import ContainerAnnotation
from .annotator_for_clinical_data_v1 import ContainerGroup
from .annotator_for_clinical_data_v1 import DeployCartridgeResponse
from .annotator_for_clinical_data_v1 import Disambiguation
from .annotator_for_clinical_data_v1 import EjectionFractionAnnotation
from .annotator_for_clinical_data_v1 import Entity
from .annotator_for_clinical_data_v1 import Flow
from .annotator_for_clinical_data_v1 import FlowEntry
from .annotator_for_clinical_data_v1 import LabValueAnnotation
from .annotator_for_clinical_data_v1 import ListStringWrapper
from .annotator_for_clinical_data_v1 import MedicationAnnotation
from .annotator_for_clinical_data_v1 import Name
from .annotator_for_clinical_data_v1 import NegatedSpan
from .annotator_for_clinical_data_v1 import NluEntities
from .annotator_for_clinical_data_v1 import Node
from .annotator_for_clinical_data_v1 import Procedure
from .annotator_for_clinical_data_v1 import Relations
from .annotator_for_clinical_data_v1 import RequestContainer
from .annotator_for_clinical_data_v1 import Section
from .annotator_for_clinical_data_v1 import SectionTrigger
from .annotator_for_clinical_data_v1 import ServiceError
from .annotator_for_clinical_data_v1 import ServiceStatus
from .annotator_for_clinical_data_v1 import Smoking
from .annotator_for_clinical_data_v1 import SpellCorrectedText
from .annotator_for_clinical_data_v1 import SpellingCorrection
from .annotator_for_clinical_data_v1 import Suggestion
from .annotator_for_clinical_data_v1 import SymptomDisease
from .annotator_for_clinical_data_v1 import UnstructuredContainer
from .annotator_for_clinical_data_v1 import ACDException
from .annotator_for_clinical_data_v1 import InsightModelData
from .annotator_for_clinical_data_v1 import Temporal

#from .util import CustomDeserializer
#from .util import CustomCollection
